Crate livekit_data_stream

Crate livekit_data_stream 

LiveKit Data Stream

Important: This is an internal crate that powers the data streams feature in LiveKit client SDKs (including Rust and others) and is not usable directly.

To use data streams in your application, please use the public APIs provided by the livekit crate and other client sdks.

Modules

api
Public API re-exported by client SDKs (surfaced to end users through the livekit crate).
backend
Internal APIs used within the livekit SDK to power data streams.