pub struct ChunkReceived {
pub chunk: Chunk,
pub participant_identity: ParticipantIdentity,
pub topic: Option<String>,
}Expand description
A “raw chunk received” notification, which is used to trigger the deprecated [RoomEvent:::StreamChunkReceived] event.
Fields
chunk: Chunkparticipant_identity: ParticipantIdentitytopic: Option<String>Topic of the stream this chunk belongs to, or None if the associated stream id could
not be mapped to a topic.