pub struct TrailerReceived {
pub trailer: Trailer,
pub participant_identity: ParticipantIdentity,
pub topic: Option<String>,
}Expand description
A “raw trailer received” notification, which is used to trigger the deprecated [RoomEvent:::StreamTrailerReceived] event.
Fields
trailer: Trailerparticipant_identity: ParticipantIdentitytopic: Option<String>Topic of the stream this chunk belongs to, or None if the associated stream id could
not be mapped to a topic.
See ChunkReceived::topic.