OutgoingStreamManager

Struct OutgoingStreamManager 

pub struct OutgoingStreamManager { /* private fields */ }

Implementations

Source

impl OutgoingStreamManager

pub fn new() -> (Self, UnboundedRequestReceiver<DataPacket, Result<(), SendError>>)

pub async fn stream_text( &self, options: StreamTextOptions, ) -> StreamResult<TextStreamWriter>

pub async fn stream_bytes( &self, options: StreamByteOptions, ) -> StreamResult<ByteStreamWriter>

pub async fn send_text( &self, text: &str, options: StreamTextOptions, ) -> StreamResult<TextStreamInfo>

pub async fn send_bytes( &self, data: impl AsRef<[u8]>, options: StreamByteOptions, ) -> StreamResult<ByteStreamInfo>

Send bytes to participants in the room.

This method sends an in-memory blob of bytes to participants in the room as a byte stream. It opens a stream using the provided options, writes the entire buffer, and closes the stream before returning.

The total_length in the header is set from the provided data and is not overridable by options.total_length.

pub async fn send_file( &self, path: impl AsRef<Path>, options: StreamByteOptions, ) -> StreamResult<ByteStreamInfo>