Crate livekit_data_stream

Crate livekit_data_stream 

LiveKit Data Stream

Important: This is an internal crate that powers the data streams feature in LiveKit client SDKs (including Rust and others) and is not usable directly.

To use data streams in your application, please use the public APIs provided by the livekit crate and other client sdks.

Structs

ByteStreamInfo
Information about a byte data stream.
ByteStreamReader
Reader for an incoming byte data stream.
ByteStreamWriter
Writer for an open byte data stream.
IncomingStreamManager
OutgoingStreamManager
SendError
Error returned by the packet transport when a data-stream packet fails to send.
StreamByteOptions
Options used when opening an outgoing byte data stream.
StreamTextOptions
Options used when opening an outgoing text data stream.
TextStreamInfo
Information about a text data stream.
TextStreamReader
Reader for an incoming text data stream.
TextStreamWriter
Writer for an open text data stream.

Enums

AnyStreamReader
OperationType
Operation type for text streams.
StreamError
Error type for data stream operations.

Traits

StreamReader
Reader for an incoming data stream.
StreamWriter
Writer for an open data stream.

Type Aliases

StreamResult
Result type for data stream operations.