pub struct Manager { /* private fields */ }Implementations
Sourceimpl Manager
impl Manager
pub fn new() -> (Self, UnboundedRequestReceiver<DataPacket, Result<(), SendError>>)
pub async fn stream_text( &self, options: StreamTextOptions, ) -> StreamResult<TextStreamWriter>
pub async fn stream_bytes( &self, options: StreamByteOptions, ) -> StreamResult<ByteStreamWriter>
pub async fn send_text( &self, text: &str, options: StreamTextOptions, remote_participant_registry: &dyn RemoteParticipantRegistry, ) -> StreamResult<TextStreamInfo>
Sourcepub async fn send_bytes(
&self,
data: impl AsRef<[u8]>,
options: StreamByteOptions,
remote_participant_registry: &dyn RemoteParticipantRegistry,
) -> StreamResult<ByteStreamInfo>
pub async fn send_bytes( &self, data: impl AsRef<[u8]>, options: StreamByteOptions, remote_participant_registry: &dyn RemoteParticipantRegistry, ) -> StreamResult<ByteStreamInfo>
Send bytes to participants in the room.
This method sends an in-memory blob of bytes to participants in the room as a byte stream. It opens a stream using the provided options, writes the entire buffer, and closes the stream before returning.
The total_length in the header is set from the provided data and is not
overridable by options.total_length. The header defaults name to "unknown"
and mime_type to "application/octet-stream".
Sourcepub async fn send_file(
&self,
path: impl AsRef<Path>,
options: StreamByteOptions,
remote_participant_registry: &dyn RemoteParticipantRegistry,
) -> StreamResult<ByteStreamInfo>
pub async fn send_file( &self, path: impl AsRef<Path>, options: StreamByteOptions, remote_participant_registry: &dyn RemoteParticipantRegistry, ) -> StreamResult<ByteStreamInfo>
Streams a file from disk to participants as a byte stream.
Never uses the inline single-packet path (deciding inline-eligibility would require buffering and compressing the whole file up front). Compresses when every recipient supports it. The whole file is never buffered in memory at once.